@@ -45,6 +45,7 @@
 #define HAVE_INTTYPES_H 1
 /* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
+#define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
@@ -86,6 +87,7 @@
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
+#define HAVE_SYS_SYSCALL_H 1
 /* #undef HAVE_SYS_TERMCAP_H */
 /* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
@@ -93,6 +95,7 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -117,6 +120,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
+/* #undef HAVE_SYSTEMD */
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -162,6 +166,7 @@
 #define HAVE_FSYNC 1
 #define HAVE_FTIME 1
 #define HAVE_GETADDRINFO 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
@@ -213,6 +218,9 @@
 #define HAVE_POLL 1
 /* #undef HAVE_PORT_CREATE */
 #define HAVE_POSIX_FALLOCATE 1
+#define HAVE_LINUX_FALLOC_H 1
+#define HAVE_FALLOCATE 1
+#define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
 /* #undef HAVE_PAUSE_INSTRUCTION */
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
@@ -317,6 +325,8 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
+#define STRUCT_TIMESPEC_HAS_TV_SEC 1
+#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
@@ -396,7 +406,7 @@
 
 #define HAVE_MBSTATE_T 1
 
-#define MAX_INDEXES 64
+#define MAX_INDEXES 64U
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -457,7 +467,7 @@
 
 #define HAVE_WEAK_SYMBOL 1
 #define HAVE_ABI_CXA_DEMANGLE 1
-
+#define HAVE_ATTRIBUTE_CLEANUP 1
 
 #define HAVE_POSIX_SIGNALS 1
 /* #undef HAVE_BSD_SIGNALS */
@@ -468,7 +478,6 @@
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
-/* #undef MY_ATOMIC_MODE_RWLOCKS */
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
@@ -489,6 +498,7 @@
 
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "aarch64"
+#define DEFAULT_MACHINE "aarch64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -514,6 +524,10 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
+#if (_MSC_VER > 1800)
+#define tzname _tzname
+#define P_tmpdir "C:\\TEMP"
+#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
@@ -522,7 +536,7 @@
 
 /* We don't want the min/max macros */
 #ifdef __WIN__
-#define NOMINMAX
+#define NOMINMAX 1
 #endif
 
 /*
@@ -531,7 +545,6 @@
 #define ENABLED_LOCAL_INFILE 1
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
-/* #undef BACKUP_TEST */
 /* #undef CYBOZU */
 /* #undef USE_SYMDIR */
 
@@ -587,7 +600,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-
+#define HAVE_EncryptAes128Ctr 1
+#define HAVE_EncryptAes128Gcm 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -604,15 +618,11 @@
 #define WITH_MYISAM_STORAGE_ENGINE 1
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
-#define WITH_INNOBASE_STORAGE_ENGINE 1
+/* #undef WITH_INNOBASE_STORAGE_ENGINE */
 #define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
-/* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
-#if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
-# define HAVE_NDB_BINLOG 1
-#endif
 #define WITH_ARIA_STORAGE_ENGINE 1
 #define USE_ARIA_FOR_TMP_TABLES 1
 
@@ -628,17 +638,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 22
+#define MYSQL_VERSION_MINOR 1
+#define MYSQL_VERSION_PATCH 9
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.22"
+#define PACKAGE_STRING "MySQL Server 10.1.9"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.22"
-#define VERSION "10.0.22"
+#define PACKAGE_VERSION "10.1.9"
+#define VERSION "10.1.9"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
@@ -648,6 +658,12 @@
 #define SIZEOF_TIME_T 8
 /* #undef TIME_T_UNSIGNED */
 
+#ifndef EMBEDDED_LIBRARY
+/* #undef WSREP_INTERFACE_VERSION */
+#define WITH_WSREP 1
+#define WSREP_PROC_INFO 1
+#endif
+
 #ifdef _AIX
 /*
   AIX includes inttypes.h from sys/types.h
